API
===

.. automodule:: hdf5_reader_service

    ``hdf5_reader_service``
    -----------------------------------

This is the internal API reference for hdf5_reader_service

.. data:: hdf5_reader_service.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm
